Class: ChargeBee::HostedPage
- Defined in:
- lib/chargebee/models/hosted_page.rb
Defined Under Namespace
Classes: Content
Instance Attribute Summary collapse
-
#business_entity_id ⇒ Object
Returns the value of attribute business_entity_id.
-
#checkout_info ⇒ Object
Returns the value of attribute checkout_info.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#embed ⇒ Object
Returns the value of attribute embed.
-
#expires_at ⇒ Object
Returns the value of attribute expires_at.
-
#failure_reason ⇒ Object
Returns the value of attribute failure_reason.
-
#id ⇒ Object
Returns the value of attribute id.
-
#layout ⇒ Object
Returns the value of attribute layout.
-
#pass_thru_content ⇒ Object
Returns the value of attribute pass_thru_content.
-
#resource_version ⇒ Object
Returns the value of attribute resource_version.
-
#state ⇒ Object
Returns the value of attribute state.
-
#type ⇒ Object
Returns the value of attribute type.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
-
#url ⇒ Object
Returns the value of attribute url.
Class Method Summary collapse
- .accept_quote(params, env = nil, headers = {}) ⇒ Object
- .acknowledge(id, env = nil, headers = {}) ⇒ Object
- .checkout_existing(params, env = nil, headers = {}) ⇒ Object
- .checkout_existing_for_items(params, env = nil, headers = {}) ⇒ Object
- .checkout_gift(params, env = nil, headers = {}) ⇒ Object
- .checkout_gift_for_items(params = {}, env = nil, headers = {}) ⇒ Object
-
.checkout_new(params, env = nil, headers = {}) ⇒ Object
OPERATIONS ———–.
- .checkout_new_for_items(params, env = nil, headers = {}) ⇒ Object
- .checkout_one_time(params = {}, env = nil, headers = {}) ⇒ Object
- .checkout_one_time_for_items(params, env = nil, headers = {}) ⇒ Object
- .claim_gift(params, env = nil, headers = {}) ⇒ Object
- .collect_now(params, env = nil, headers = {}) ⇒ Object
- .events(params, env = nil, headers = {}) ⇒ Object
- .extend_subscription(params, env = nil, headers = {}) ⇒ Object
- .list(params = {}, env = nil, headers = {}) ⇒ Object
- .manage_payment_sources(params, env = nil, headers = {}) ⇒ Object
- .pre_cancel(params, env = nil, headers = {}) ⇒ Object
- .retrieve(id, env = nil, headers = {}) ⇒ Object
- .retrieve_agreement_pdf(params, env = nil, headers = {}) ⇒ Object
-
.update_card(params, env = nil, headers = {}) ⇒ Object
deprecated
Deprecated.
This method is deprecated and will be removed in a future version.
-
.update_payment_method(params, env = nil, headers = {}) ⇒ Object
deprecated
Deprecated.
This method is deprecated and will be removed in a future version.
- .view_voucher(params, env = nil, headers = {}) ⇒ Object
Instance Method Summary collapse
Methods inherited from Model
construct, #init_dependant, #init_dependant_list, #initialize, #inspect, #load, #method_missing, #replace_white_space_with_underscore, #respond_to_missing?, #to_s, uri_path
Constructor Details
This class inherits a constructor from ChargeBee::Model
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class ChargeBee::Model
Instance Attribute Details
#business_entity_id ⇒ Object
Returns the value of attribute business_entity_id.
4 5 6 |
# File 'lib/chargebee/models/hosted_page.rb', line 4 def business_entity_id @business_entity_id end |
#checkout_info ⇒ Object
Returns the value of attribute checkout_info.
4 5 6 |
# File 'lib/chargebee/models/hosted_page.rb', line 4 def checkout_info @checkout_info end |
#created_at ⇒ Object
Returns the value of attribute created_at.
4 5 6 |
# File 'lib/chargebee/models/hosted_page.rb', line 4 def created_at @created_at end |
#embed ⇒ Object
Returns the value of attribute embed.
4 5 6 |
# File 'lib/chargebee/models/hosted_page.rb', line 4 def @embed end |
#expires_at ⇒ Object
Returns the value of attribute expires_at.
4 5 6 |
# File 'lib/chargebee/models/hosted_page.rb', line 4 def expires_at @expires_at end |
#failure_reason ⇒ Object
Returns the value of attribute failure_reason.
4 5 6 |
# File 'lib/chargebee/models/hosted_page.rb', line 4 def failure_reason @failure_reason end |
#id ⇒ Object
Returns the value of attribute id.
4 5 6 |
# File 'lib/chargebee/models/hosted_page.rb', line 4 def id @id end |
#layout ⇒ Object
Returns the value of attribute layout.
4 5 6 |
# File 'lib/chargebee/models/hosted_page.rb', line 4 def layout @layout end |
#pass_thru_content ⇒ Object
Returns the value of attribute pass_thru_content.
4 5 6 |
# File 'lib/chargebee/models/hosted_page.rb', line 4 def pass_thru_content @pass_thru_content end |
#resource_version ⇒ Object
Returns the value of attribute resource_version.
4 5 6 |
# File 'lib/chargebee/models/hosted_page.rb', line 4 def resource_version @resource_version end |
#state ⇒ Object
Returns the value of attribute state.
4 5 6 |
# File 'lib/chargebee/models/hosted_page.rb', line 4 def state @state end |
#type ⇒ Object
Returns the value of attribute type.
4 5 6 |
# File 'lib/chargebee/models/hosted_page.rb', line 4 def type @type end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
4 5 6 |
# File 'lib/chargebee/models/hosted_page.rb', line 4 def updated_at @updated_at end |
#url ⇒ Object
Returns the value of attribute url.
4 5 6 |
# File 'lib/chargebee/models/hosted_page.rb', line 4 def url @url end |
Class Method Details
.accept_quote(params, env = nil, headers = {}) ⇒ Object
113 114 115 116 117 118 119 120 |
# File 'lib/chargebee/models/hosted_page.rb', line 113 def self.accept_quote(params, env=nil, headers={}) jsonKeys = { } = { :isIdempotent => true } Request.send('post', uri_path("hosted_pages","accept_quote"), params, env, headers,nil, false, jsonKeys, ) end |
.acknowledge(id, env = nil, headers = {}) ⇒ Object
167 168 169 170 171 172 173 174 |
# File 'lib/chargebee/models/hosted_page.rb', line 167 def self.acknowledge(id, env=nil, headers={}) jsonKeys = { } = { :isIdempotent => true } Request.send('post', uri_path("hosted_pages",id.to_s,"acknowledge"), {}, env, headers,nil, false, jsonKeys, ) end |
.checkout_existing(params, env = nil, headers = {}) ⇒ Object
57 58 59 60 61 62 63 64 |
# File 'lib/chargebee/models/hosted_page.rb', line 57 def self.checkout_existing(params, env=nil, headers={}) jsonKeys = { } = { :isIdempotent => true } Request.send('post', uri_path("hosted_pages","checkout_existing"), params, env, headers,nil, false, jsonKeys, ) end |
.checkout_existing_for_items(params, env = nil, headers = {}) ⇒ Object
66 67 68 69 70 71 72 73 |
# File 'lib/chargebee/models/hosted_page.rb', line 66 def self.checkout_existing_for_items(params, env=nil, headers={}) jsonKeys = { } = { :isIdempotent => true } Request.send('post', uri_path("hosted_pages","checkout_existing_for_items"), params, env, headers,nil, false, jsonKeys, ) end |
.checkout_gift(params, env = nil, headers = {}) ⇒ Object
131 132 133 134 135 136 137 138 |
# File 'lib/chargebee/models/hosted_page.rb', line 131 def self.checkout_gift(params, env=nil, headers={}) jsonKeys = { } = { :isIdempotent => true } Request.send('post', uri_path("hosted_pages","checkout_gift"), params, env, headers,nil, false, jsonKeys, ) end |
.checkout_gift_for_items(params = {}, env = nil, headers = {}) ⇒ Object
140 141 142 143 144 145 146 147 |
# File 'lib/chargebee/models/hosted_page.rb', line 140 def self.checkout_gift_for_items(params={}, env=nil, headers={}) jsonKeys = { } = { :isIdempotent => true } Request.send('post', uri_path("hosted_pages","checkout_gift_for_items"), params, env, headers,nil, false, jsonKeys, ) end |
.checkout_new(params, env = nil, headers = {}) ⇒ Object
OPERATIONS
21 22 23 24 25 26 27 28 |
# File 'lib/chargebee/models/hosted_page.rb', line 21 def self.checkout_new(params, env=nil, headers={}) jsonKeys = { } = { :isIdempotent => true } Request.send('post', uri_path("hosted_pages","checkout_new"), params, env, headers,nil, false, jsonKeys, ) end |
.checkout_new_for_items(params, env = nil, headers = {}) ⇒ Object
48 49 50 51 52 53 54 55 |
# File 'lib/chargebee/models/hosted_page.rb', line 48 def self.checkout_new_for_items(params, env=nil, headers={}) jsonKeys = { } = { :isIdempotent => true } Request.send('post', uri_path("hosted_pages","checkout_new_for_items"), params, env, headers,nil, false, jsonKeys, ) end |
.checkout_one_time(params = {}, env = nil, headers = {}) ⇒ Object
30 31 32 33 34 35 36 37 |
# File 'lib/chargebee/models/hosted_page.rb', line 30 def self.checkout_one_time(params={}, env=nil, headers={}) jsonKeys = { } = { :isIdempotent => true } Request.send('post', uri_path("hosted_pages","checkout_one_time"), params, env, headers,nil, false, jsonKeys, ) end |
.checkout_one_time_for_items(params, env = nil, headers = {}) ⇒ Object
39 40 41 42 43 44 45 46 |
# File 'lib/chargebee/models/hosted_page.rb', line 39 def self.checkout_one_time_for_items(params, env=nil, headers={}) jsonKeys = { } = { :isIdempotent => true } Request.send('post', uri_path("hosted_pages","checkout_one_time_for_items"), params, env, headers,nil, false, jsonKeys, ) end |
.claim_gift(params, env = nil, headers = {}) ⇒ Object
149 150 151 152 153 154 155 156 |
# File 'lib/chargebee/models/hosted_page.rb', line 149 def self.claim_gift(params, env=nil, headers={}) jsonKeys = { } = { :isIdempotent => true } Request.send('post', uri_path("hosted_pages","claim_gift"), params, env, headers,nil, false, jsonKeys, ) end |
.collect_now(params, env = nil, headers = {}) ⇒ Object
104 105 106 107 108 109 110 111 |
# File 'lib/chargebee/models/hosted_page.rb', line 104 def self.collect_now(params, env=nil, headers={}) jsonKeys = { } = { :isIdempotent => true } Request.send('post', uri_path("hosted_pages","collect_now"), params, env, headers,nil, false, jsonKeys, ) end |
.events(params, env = nil, headers = {}) ⇒ Object
199 200 201 202 203 204 205 206 207 |
# File 'lib/chargebee/models/hosted_page.rb', line 199 def self.events(params, env=nil, headers={}) jsonKeys = { :event_data => 0, } = { :isIdempotent => true } Request.send('post', uri_path("hosted_pages","events"), params, env, headers,nil, false, jsonKeys, ) end |
.extend_subscription(params, env = nil, headers = {}) ⇒ Object
122 123 124 125 126 127 128 129 |
# File 'lib/chargebee/models/hosted_page.rb', line 122 def self.extend_subscription(params, env=nil, headers={}) jsonKeys = { } = { :isIdempotent => true } Request.send('post', uri_path("hosted_pages","extend_subscription"), params, env, headers,nil, false, jsonKeys, ) end |
.list(params = {}, env = nil, headers = {}) ⇒ Object
183 184 185 186 187 188 |
# File 'lib/chargebee/models/hosted_page.rb', line 183 def self.list(params={}, env=nil, headers={}) jsonKeys = { } = {} Request.send_list_request('get', uri_path("hosted_pages"), params, env, headers,nil, false, jsonKeys, ) end |
.manage_payment_sources(params, env = nil, headers = {}) ⇒ Object
95 96 97 98 99 100 101 102 |
# File 'lib/chargebee/models/hosted_page.rb', line 95 def self.manage_payment_sources(params, env=nil, headers={}) jsonKeys = { } = { :isIdempotent => true } Request.send('post', uri_path("hosted_pages","manage_payment_sources"), params, env, headers,nil, false, jsonKeys, ) end |
.pre_cancel(params, env = nil, headers = {}) ⇒ Object
190 191 192 193 194 195 196 197 |
# File 'lib/chargebee/models/hosted_page.rb', line 190 def self.pre_cancel(params, env=nil, headers={}) jsonKeys = { } = { :isIdempotent => true } Request.send('post', uri_path("hosted_pages","pre_cancel"), params, env, headers,nil, false, jsonKeys, ) end |
.retrieve(id, env = nil, headers = {}) ⇒ Object
176 177 178 179 180 181 |
# File 'lib/chargebee/models/hosted_page.rb', line 176 def self.retrieve(id, env=nil, headers={}) jsonKeys = { } = {} Request.send('get', uri_path("hosted_pages",id.to_s), {}, env, headers,nil, false, jsonKeys, ) end |
.retrieve_agreement_pdf(params, env = nil, headers = {}) ⇒ Object
158 159 160 161 162 163 164 165 |
# File 'lib/chargebee/models/hosted_page.rb', line 158 def self.retrieve_agreement_pdf(params, env=nil, headers={}) jsonKeys = { } = { :isIdempotent => true } Request.send('post', uri_path("hosted_pages","retrieve_agreement_pdf"), params, env, headers,nil, false, jsonKeys, ) end |
.update_card(params, env = nil, headers = {}) ⇒ Object
This method is deprecated and will be removed in a future version.
76 77 78 79 80 81 82 83 |
# File 'lib/chargebee/models/hosted_page.rb', line 76 def self.update_card(params, env=nil, headers={}) jsonKeys = { } = { :isIdempotent => true } Request.send('post', uri_path("hosted_pages","update_card"), params, env, headers,nil, false, jsonKeys, ) end |
.update_payment_method(params, env = nil, headers = {}) ⇒ Object
This method is deprecated and will be removed in a future version.
86 87 88 89 90 91 92 93 |
# File 'lib/chargebee/models/hosted_page.rb', line 86 def self.update_payment_method(params, env=nil, headers={}) jsonKeys = { } = { :isIdempotent => true } Request.send('post', uri_path("hosted_pages","update_payment_method"), params, env, headers,nil, false, jsonKeys, ) end |
.view_voucher(params, env = nil, headers = {}) ⇒ Object
209 210 211 212 213 214 215 216 |
# File 'lib/chargebee/models/hosted_page.rb', line 209 def self.view_voucher(params, env=nil, headers={}) jsonKeys = { } = { :isIdempotent => true } Request.send('post', uri_path("hosted_pages","view_voucher"), params, env, headers,nil, false, jsonKeys, ) end |