Class: ChargeBee::Invoice

Inherits:
Model
  • Object
show all
Defined in:
lib/chargebee/models/invoice.rb

Defined Under Namespace

Classes: AdjustmentCreditNote, AppliedCredit, BillingAddress, Discount, DunningAttempt, Einvoice, ExchangeRate, IssuedCreditNote, LineItem, LineItemAddress, LineItemCredit, LineItemDiscount, LineItemTax, LineItemTier, LinkedOrder, LinkedPayment, Note, ReferenceTransaction, ShippingAddress, SiteDetailsAtCreation, StatementDescriptor, Tax, TaxOrigin

Instance Attribute Summary collapse

Class Method Summary collapse

Methods inherited from Model

construct, #init_dependant, #init_dependant_list, #initialize, #inspect, #load, #method_missing, #replace_white_space_with_underscore, #respond_to_missing?, #to_s, uri_path

Constructor Details

This class inherits a constructor from ChargeBee::Model

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class ChargeBee::Model

Instance Attribute Details

#adjustment_credit_notesObject

Returns the value of attribute adjustment_credit_notes.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def adjustment_credit_notes
  @adjustment_credit_notes
end

#amount_adjustedObject

Returns the value of attribute amount_adjusted.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def amount_adjusted
  @amount_adjusted
end

#amount_dueObject

Returns the value of attribute amount_due.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def amount_due
  @amount_due
end

#amount_paidObject

Returns the value of attribute amount_paid.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def amount_paid
  @amount_paid
end

#amount_to_collectObject

Returns the value of attribute amount_to_collect.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def amount_to_collect
  @amount_to_collect
end

#applied_creditsObject

Returns the value of attribute applied_credits.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def applied_credits
  @applied_credits
end

#billing_addressObject

Returns the value of attribute billing_address.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def billing_address
  @billing_address
end

#business_entity_idObject

Returns the value of attribute business_entity_id.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def business_entity_id
  @business_entity_id
end

#channelObject

Returns the value of attribute channel.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def channel
  @channel
end

#credits_appliedObject

Returns the value of attribute credits_applied.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def credits_applied
  @credits_applied
end

#currency_codeObject

Returns the value of attribute currency_code.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def currency_code
  @currency_code
end

#customer_idObject

Returns the value of attribute customer_id.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def customer_id
  @customer_id
end

#dateObject

Returns the value of attribute date.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def date
  @date
end

#deletedObject

Returns the value of attribute deleted.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def deleted
  @deleted
end

#discountsObject

Returns the value of attribute discounts.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def discounts
  @discounts
end

#due_dateObject

Returns the value of attribute due_date.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def due_date
  @due_date
end

#dunning_attemptsObject

Returns the value of attribute dunning_attempts.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def dunning_attempts
  @dunning_attempts
end

#dunning_statusObject

Returns the value of attribute dunning_status.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def dunning_status
  @dunning_status
end

#einvoiceObject

Returns the value of attribute einvoice.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def einvoice
  @einvoice
end

#exchange_rateObject

Returns the value of attribute exchange_rate.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def exchange_rate
  @exchange_rate
end

#exchange_ratesObject

Returns the value of attribute exchange_rates.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def exchange_rates
  @exchange_rates
end

#expected_payment_dateObject

Returns the value of attribute expected_payment_date.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def expected_payment_date
  @expected_payment_date
end

#first_invoiceObject

Returns the value of attribute first_invoice.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def first_invoice
  @first_invoice
end

#generated_atObject

Returns the value of attribute generated_at.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def generated_at
  @generated_at
end

#has_advance_chargesObject

Returns the value of attribute has_advance_charges.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def has_advance_charges
  @has_advance_charges
end

#idObject

Returns the value of attribute id.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def id
  @id
end

#is_giftedObject

Returns the value of attribute is_gifted.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def is_gifted
  @is_gifted
end

#issued_credit_notesObject

Returns the value of attribute issued_credit_notes.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def issued_credit_notes
  @issued_credit_notes
end

#line_item_addressesObject

Returns the value of attribute line_item_addresses.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def line_item_addresses
  @line_item_addresses
end

#line_item_creditsObject

Returns the value of attribute line_item_credits.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def line_item_credits
  @line_item_credits
end

#line_item_discountsObject

Returns the value of attribute line_item_discounts.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def line_item_discounts
  @line_item_discounts
end

#line_item_taxesObject

Returns the value of attribute line_item_taxes.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def line_item_taxes
  @line_item_taxes
end

#line_item_tiersObject

Returns the value of attribute line_item_tiers.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def line_item_tiers
  @line_item_tiers
end

#line_itemsObject

Returns the value of attribute line_items.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def line_items
  @line_items
end

#line_items_next_offsetObject

Returns the value of attribute line_items_next_offset.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def line_items_next_offset
  @line_items_next_offset
end

#linked_ordersObject

Returns the value of attribute linked_orders.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def linked_orders
  @linked_orders
end

#linked_paymentsObject

Returns the value of attribute linked_payments.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def linked_payments
  @linked_payments
end

#local_currency_codeObject

Returns the value of attribute local_currency_code.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def local_currency_code
  @local_currency_code
end

#local_currency_exchange_rateObject

Returns the value of attribute local_currency_exchange_rate.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def local_currency_exchange_rate
  @local_currency_exchange_rate
end

#net_term_daysObject

Returns the value of attribute net_term_days.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def net_term_days
  @net_term_days
end

#new_sales_amountObject

Returns the value of attribute new_sales_amount.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def new_sales_amount
  @new_sales_amount
end

#next_retry_atObject

Returns the value of attribute next_retry_at.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def next_retry_at
  @next_retry_at
end

#notesObject

Returns the value of attribute notes.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def notes
  @notes
end

Returns the value of attribute paid_at.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def paid_at
  @paid_at
end

#payment_ownerObject

Returns the value of attribute payment_owner.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def payment_owner
  @payment_owner
end

#po_numberObject

Returns the value of attribute po_number.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def po_number
  @po_number
end

#price_typeObject

Returns the value of attribute price_type.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def price_type
  @price_type
end

#recurringObject

Returns the value of attribute recurring.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def recurring
  @recurring
end

#reference_transactionsObject

Returns the value of attribute reference_transactions.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def reference_transactions
  @reference_transactions
end

#resource_versionObject

Returns the value of attribute resource_version.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def resource_version
  @resource_version
end

#round_off_amountObject

Returns the value of attribute round_off_amount.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def round_off_amount
  @round_off_amount
end

#shipping_addressObject

Returns the value of attribute shipping_address.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def shipping_address
  @shipping_address
end

#site_details_at_creationObject

Returns the value of attribute site_details_at_creation.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def site_details_at_creation
  @site_details_at_creation
end

#statement_descriptorObject

Returns the value of attribute statement_descriptor.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def statement_descriptor
  @statement_descriptor
end

#statusObject

Returns the value of attribute status.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def status
  @status
end

#sub_totalObject

Returns the value of attribute sub_total.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def sub_total
  @sub_total
end

#sub_total_in_local_currencyObject

Returns the value of attribute sub_total_in_local_currency.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def sub_total_in_local_currency
  @sub_total_in_local_currency
end

#subscription_idObject

Returns the value of attribute subscription_id.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def subscription_id
  @subscription_id
end

#taxObject

Returns the value of attribute tax.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def tax
  @tax
end

#tax_categoryObject

Returns the value of attribute tax_category.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def tax_category
  @tax_category
end

#tax_originObject

Returns the value of attribute tax_origin.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def tax_origin
  @tax_origin
end

#taxesObject

Returns the value of attribute taxes.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def taxes
  @taxes
end

#term_finalizedObject

Returns the value of attribute term_finalized.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def term_finalized
  @term_finalized
end

#totalObject

Returns the value of attribute total.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def total
  @total
end

#total_in_local_currencyObject

Returns the value of attribute total_in_local_currency.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def total_in_local_currency
  @total_in_local_currency
end

#updated_atObject

Returns the value of attribute updated_at.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def updated_at
  @updated_at
end

#vat_numberObject

Returns the value of attribute vat_number.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def vat_number
  @vat_number
end

#vat_number_prefixObject

Returns the value of attribute vat_number_prefix.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def vat_number_prefix
  @vat_number_prefix
end

#void_reason_codeObject

Returns the value of attribute void_reason_code.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def void_reason_code
  @void_reason_code
end

#voided_atObject

Returns the value of attribute voided_at.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def voided_at
  @voided_at
end

#write_off_amountObject

Returns the value of attribute write_off_amount.



96
97
98
# File 'lib/chargebee/models/invoice.rb', line 96

def write_off_amount
  @write_off_amount
end

Class Method Details

.add_addon_charge(id, params, env = nil, headers = {}) ⇒ Object



296
297
298
299
300
301
302
303
# File 'lib/chargebee/models/invoice.rb', line 296

def self.add_addon_charge(id, params, env=nil, headers={})
  jsonKeys = { 
  }
  options = {
      :isIdempotent => true
    }
  Request.send('post', uri_path("invoices",id.to_s,"add_addon_charge"), params, env, headers,nil, false, jsonKeys, options, "invoice", "addAddonCharge")
end

.add_charge(id, params, env = nil, headers = {}) ⇒ Object



287
288
289
290
291
292
293
294
# File 'lib/chargebee/models/invoice.rb', line 287

def self.add_charge(id, params, env=nil, headers={})
  jsonKeys = { 
  }
  options = {
      :isIdempotent => true
    }
  Request.send('post', uri_path("invoices",id.to_s,"add_charge"), params, env, headers,nil, false, jsonKeys, options, "invoice", "addCharge")
end

.add_charge_item(id, params, env = nil, headers = {}) ⇒ Object



305
306
307
308
309
310
311
312
# File 'lib/chargebee/models/invoice.rb', line 305

def self.add_charge_item(id, params, env=nil, headers={})
  jsonKeys = { 
  }
  options = {
      :isIdempotent => true
    }
  Request.send('post', uri_path("invoices",id.to_s,"add_charge_item"), params, env, headers,nil, false, jsonKeys, options, "invoice", "addChargeItem")
end

.apply_credits(id, params = {}, env = nil, headers = {}) ⇒ Object



225
226
227
228
229
230
231
232
# File 'lib/chargebee/models/invoice.rb', line 225

def self.apply_credits(id, params={}, env=nil, headers={})
  jsonKeys = { 
  }
  options = {
      :isIdempotent => true
    }
  Request.send('post', uri_path("invoices",id.to_s,"apply_credits"), params, env, headers,nil, false, jsonKeys, options, "invoice", "applyCredits")
end

.apply_payment_schedule_scheme(id, params, env = nil, headers = {}) ⇒ Object



431
432
433
434
435
436
437
438
# File 'lib/chargebee/models/invoice.rb', line 431

def self.apply_payment_schedule_scheme(id, params, env=nil, headers={})
  jsonKeys = { 
  }
  options = {
      :isIdempotent => true
    }
  Request.send('post', uri_path("invoices",id.to_s,"apply_payment_schedule_scheme"), params, env, headers,nil, false, jsonKeys, options, "invoice", "applyPaymentScheduleScheme")
end

.apply_payments(id, params = {}, env = nil, headers = {}) ⇒ Object



198
199
200
201
202
203
204
205
# File 'lib/chargebee/models/invoice.rb', line 198

def self.apply_payments(id, params={}, env=nil, headers={})
  jsonKeys = { 
  }
  options = {
      :isIdempotent => true
    }
  Request.send('post', uri_path("invoices",id.to_s,"apply_payments"), params, env, headers,nil, false, jsonKeys, options, "invoice", "applyPayments")
end

.charge(params, env = nil, headers = {}) ⇒ Object



134
135
136
137
138
139
140
141
# File 'lib/chargebee/models/invoice.rb', line 134

def self.charge(params, env=nil, headers={})
  jsonKeys = { 
  }
  options = {
      :isIdempotent => true
    }
  Request.send('post', uri_path("invoices","charge"), params, env, headers,nil, false, jsonKeys, options, "invoice", "charge")
end

.charge_addon(params, env = nil, headers = {}) ⇒ Object



143
144
145
146
147
148
149
150
# File 'lib/chargebee/models/invoice.rb', line 143

def self.charge_addon(params, env=nil, headers={})
  jsonKeys = { 
  }
  options = {
      :isIdempotent => true
    }
  Request.send('post', uri_path("invoices","charge_addon"), params, env, headers,nil, false, jsonKeys, options, "invoice", "chargeAddon")
end

.close(id, params = {}, env = nil, headers = {}) ⇒ Object



314
315
316
317
318
319
320
321
# File 'lib/chargebee/models/invoice.rb', line 314

def self.close(id, params={}, env=nil, headers={})
  jsonKeys = { 
  }
  options = {
      :isIdempotent => true
    }
  Request.send('post', uri_path("invoices",id.to_s,"close"), params, env, headers,nil, false, jsonKeys, options, "invoice", "close")
end

.collect_payment(id, params = {}, env = nil, headers = {}) ⇒ Object



323
324
325
326
327
328
329
330
# File 'lib/chargebee/models/invoice.rb', line 323

def self.collect_payment(id, params={}, env=nil, headers={})
  jsonKeys = { 
  }
  options = {
      :isIdempotent => true
    }
  Request.send('post', uri_path("invoices",id.to_s,"collect_payment"), params, env, headers,nil, false, jsonKeys, options, "invoice", "collectPayment")
end

.create(params = {}, env = nil, headers = {}) ⇒ Object

OPERATIONS



112
113
114
115
116
117
118
119
120
121
# File 'lib/chargebee/models/invoice.rb', line 112

def self.create(params={}, env=nil, headers={})
  jsonKeys = { 
      :additional_information => 1,
      :billing_address => 1,
  }
  options = {
      :isIdempotent => true
    }
  Request.send('post', uri_path("invoices"), params, env, headers,nil, false, jsonKeys, options, "invoice", "create")
end

.create_for_charge_item(params, env = nil, headers = {}) ⇒ Object

Deprecated.

This method is deprecated and will be removed in a future version.



153
154
155
156
157
158
159
160
# File 'lib/chargebee/models/invoice.rb', line 153

def self.create_for_charge_item(params, env=nil, headers={})
  jsonKeys = { 
  }
  options = {
      :isIdempotent => true
    }
  Request.send('post', uri_path("invoices","create_for_charge_item"), params, env, headers,nil, false, jsonKeys, options, "invoice", "createForChargeItem")
end

.create_for_charge_items_and_charges(params, env = nil, headers = {}) ⇒ Object



123
124
125
126
127
128
129
130
131
132
# File 'lib/chargebee/models/invoice.rb', line 123

def self.create_for_charge_items_and_charges(params, env=nil, headers={})
  jsonKeys = { 
      :additional_information => 1,
      :billing_address => 1,
  }
  options = {
      :isIdempotent => true
    }
  Request.send('post', uri_path("invoices","create_for_charge_items_and_charges"), params, env, headers,nil, false, jsonKeys, options, "invoice", "createForChargeItemsAndCharges")
end

.delete(id, params = {}, env = nil, headers = {}) ⇒ Object



413
414
415
416
417
418
419
420
# File 'lib/chargebee/models/invoice.rb', line 413

def self.delete(id, params={}, env=nil, headers={})
  jsonKeys = { 
  }
  options = {
      :isIdempotent => true
    }
  Request.send('post', uri_path("invoices",id.to_s,"delete"), params, env, headers,nil, false, jsonKeys, options, "invoice", "delete")
end

.delete_line_items(id, params = {}, env = nil, headers = {}) ⇒ Object



216
217
218
219
220
221
222
223
# File 'lib/chargebee/models/invoice.rb', line 216

def self.delete_line_items(id, params={}, env=nil, headers={})
  jsonKeys = { 
  }
  options = {
      :isIdempotent => true
    }
  Request.send('post', uri_path("invoices",id.to_s,"delete_line_items"), params, env, headers,nil, false, jsonKeys, options, "invoice", "deleteLineItems")
end

.download_einvoice(id, env = nil, headers = {}) ⇒ Object



273
274
275
276
277
278
# File 'lib/chargebee/models/invoice.rb', line 273

def self.download_einvoice(id, env=nil, headers={})
  jsonKeys = { 
  }
  options = {}
  Request.send('get', uri_path("invoices",id.to_s,"download_einvoice"), {}, env, headers,nil, false, jsonKeys, options, "invoice", "downloadEinvoice")
end

.import_invoice(params, env = nil, headers = {}) ⇒ Object



189
190
191
192
193
194
195
196
# File 'lib/chargebee/models/invoice.rb', line 189

def self.import_invoice(params, env=nil, headers={})
  jsonKeys = { 
  }
  options = {
      :isIdempotent => true
    }
  Request.send('post', uri_path("invoices","import_invoice"), params, env, headers,nil, false, jsonKeys, options, "invoice", "importInvoice")
end

.invoices_for_customer(id, params = {}, env = nil, headers = {}) ⇒ Object

Deprecated.

This method is deprecated and will be removed in a future version.



242
243
244
245
246
247
# File 'lib/chargebee/models/invoice.rb', line 242

def self.invoices_for_customer(id, params={}, env=nil, headers={})
  jsonKeys = { 
  }
  options = {}
  Request.send('get', uri_path("customers",id.to_s,"invoices"), params, env, headers,nil, false, jsonKeys, options, "invoice", "invoicesForCustomer")
end

.invoices_for_subscription(id, params = {}, env = nil, headers = {}) ⇒ Object

Deprecated.

This method is deprecated and will be removed in a future version.



250
251
252
253
254
255
# File 'lib/chargebee/models/invoice.rb', line 250

def self.invoices_for_subscription(id, params={}, env=nil, headers={})
  jsonKeys = { 
  }
  options = {}
  Request.send('get', uri_path("subscriptions",id.to_s,"invoices"), params, env, headers,nil, false, jsonKeys, options, "invoice", "invoicesForSubscription")
end

.list(params = {}, env = nil, headers = {}) ⇒ Object



234
235
236
237
238
239
# File 'lib/chargebee/models/invoice.rb', line 234

def self.list(params={}, env=nil, headers={})
  jsonKeys = { 
  }
  options = {}
  Request.send_list_request('get', uri_path("invoices"), params, env, headers,nil, false, jsonKeys, options, "invoice", "list")
end

.list_payment_reference_numbers(params = {}, env = nil, headers = {}) ⇒ Object



280
281
282
283
284
285
# File 'lib/chargebee/models/invoice.rb', line 280

def self.list_payment_reference_numbers(params={}, env=nil, headers={})
  jsonKeys = { 
  }
  options = {}
  Request.send('get', uri_path("invoices","payment_reference_numbers"), params, env, headers,nil, false, jsonKeys, options, "invoice", "listPaymentReferenceNumbers")
end

.pause_dunning(id, params, env = nil, headers = {}) ⇒ Object



171
172
173
174
175
176
177
178
# File 'lib/chargebee/models/invoice.rb', line 171

def self.pause_dunning(id, params, env=nil, headers={})
  jsonKeys = { 
  }
  options = {
      :isIdempotent => true
    }
  Request.send('post', uri_path("invoices",id.to_s,"pause_dunning"), params, env, headers,nil, false, jsonKeys, options, "invoice", "pauseDunning")
end

.payment_schedules(id, env = nil, headers = {}) ⇒ Object



440
441
442
443
444
445
# File 'lib/chargebee/models/invoice.rb', line 440

def self.payment_schedules(id, env=nil, headers={})
  jsonKeys = { 
  }
  options = {}
  Request.send('get', uri_path("invoices",id.to_s,"payment_schedules"), {}, env, headers,nil, false, jsonKeys, options, "invoice", "paymentSchedules")
end

.pdf(id, params = {}, env = nil, headers = {}) ⇒ Object



264
265
266
267
268
269
270
271
# File 'lib/chargebee/models/invoice.rb', line 264

def self.pdf(id, params={}, env=nil, headers={})
  jsonKeys = { 
  }
  options = {
      :isIdempotent => true
    }
  Request.send('post', uri_path("invoices",id.to_s,"pdf"), params, env, headers,nil, false, jsonKeys, options, "invoice", "pdf")
end

.record_payment(id, params, env = nil, headers = {}) ⇒ Object



332
333
334
335
336
337
338
339
# File 'lib/chargebee/models/invoice.rb', line 332

def self.record_payment(id, params, env=nil, headers={})
  jsonKeys = { 
  }
  options = {
      :isIdempotent => true
    }
  Request.send('post', uri_path("invoices",id.to_s,"record_payment"), params, env, headers,nil, false, jsonKeys, options, "invoice", "recordPayment")
end

.record_refund(id, params, env = nil, headers = {}) ⇒ Object



368
369
370
371
372
373
374
375
# File 'lib/chargebee/models/invoice.rb', line 368

def self.record_refund(id, params, env=nil, headers={})
  jsonKeys = { 
  }
  options = {
      :isIdempotent => true
    }
  Request.send('post', uri_path("invoices",id.to_s,"record_refund"), params, env, headers,nil, false, jsonKeys, options, "invoice", "recordRefund")
end

.record_tax_withheld(id, params, env = nil, headers = {}) ⇒ Object



341
342
343
344
345
346
347
348
# File 'lib/chargebee/models/invoice.rb', line 341

def self.record_tax_withheld(id, params, env=nil, headers={})
  jsonKeys = { 
  }
  options = {
      :isIdempotent => true
    }
  Request.send('post', uri_path("invoices",id.to_s,"record_tax_withheld"), params, env, headers,nil, false, jsonKeys, options, "invoice", "recordTaxWithheld")
end

.refund(id, params = {}, env = nil, headers = {}) ⇒ Object



359
360
361
362
363
364
365
366
# File 'lib/chargebee/models/invoice.rb', line 359

def self.refund(id, params={}, env=nil, headers={})
  jsonKeys = { 
  }
  options = {
      :isIdempotent => true
    }
  Request.send('post', uri_path("invoices",id.to_s,"refund"), params, env, headers,nil, false, jsonKeys, options, "invoice", "refund")
end

.remove_credit_note(id, params, env = nil, headers = {}) ⇒ Object



386
387
388
389
390
391
392
393
# File 'lib/chargebee/models/invoice.rb', line 386

def self.remove_credit_note(id, params, env=nil, headers={})
  jsonKeys = { 
  }
  options = {
      :isIdempotent => true
    }
  Request.send('post', uri_path("invoices",id.to_s,"remove_credit_note"), params, env, headers,nil, false, jsonKeys, options, "invoice", "removeCreditNote")
end

.remove_payment(id, params, env = nil, headers = {}) ⇒ Object



377
378
379
380
381
382
383
384
# File 'lib/chargebee/models/invoice.rb', line 377

def self.remove_payment(id, params, env=nil, headers={})
  jsonKeys = { 
  }
  options = {
      :isIdempotent => true
    }
  Request.send('post', uri_path("invoices",id.to_s,"remove_payment"), params, env, headers,nil, false, jsonKeys, options, "invoice", "removePayment")
end

.remove_tax_withheld(id, params, env = nil, headers = {}) ⇒ Object



350
351
352
353
354
355
356
357
# File 'lib/chargebee/models/invoice.rb', line 350

def self.remove_tax_withheld(id, params, env=nil, headers={})
  jsonKeys = { 
  }
  options = {
      :isIdempotent => true
    }
  Request.send('post', uri_path("invoices",id.to_s,"remove_tax_withheld"), params, env, headers,nil, false, jsonKeys, options, "invoice", "removeTaxWithheld")
end

.resend_einvoice(id, env = nil, headers = {}) ⇒ Object



447
448
449
450
451
452
453
454
# File 'lib/chargebee/models/invoice.rb', line 447

def self.resend_einvoice(id, env=nil, headers={})
  jsonKeys = { 
  }
  options = {
      :isIdempotent => true
    }
  Request.send('post', uri_path("invoices",id.to_s,"resend_einvoice"), {}, env, headers,nil, false, jsonKeys, options, "invoice", "resendEinvoice")
end

.resume_dunning(id, params = {}, env = nil, headers = {}) ⇒ Object



180
181
182
183
184
185
186
187
# File 'lib/chargebee/models/invoice.rb', line 180

def self.resume_dunning(id, params={}, env=nil, headers={})
  jsonKeys = { 
  }
  options = {
      :isIdempotent => true
    }
  Request.send('post', uri_path("invoices",id.to_s,"resume_dunning"), params, env, headers,nil, false, jsonKeys, options, "invoice", "resumeDunning")
end

.retrieve(id, params = {}, env = nil, headers = {}) ⇒ Object



257
258
259
260
261
262
# File 'lib/chargebee/models/invoice.rb', line 257

def self.retrieve(id, params={}, env=nil, headers={})
  jsonKeys = { 
  }
  options = {}
  Request.send('get', uri_path("invoices",id.to_s), params, env, headers,nil, false, jsonKeys, options, "invoice", "retrieve")
end

.send_einvoice(id, env = nil, headers = {}) ⇒ Object



456
457
458
459
460
461
462
463
# File 'lib/chargebee/models/invoice.rb', line 456

def self.send_einvoice(id, env=nil, headers={})
  jsonKeys = { 
  }
  options = {
      :isIdempotent => true
    }
  Request.send('post', uri_path("invoices",id.to_s,"send_einvoice"), {}, env, headers,nil, false, jsonKeys, options, "invoice", "sendEinvoice")
end

.stop_dunning(id, params = {}, env = nil, headers = {}) ⇒ Object



162
163
164
165
166
167
168
169
# File 'lib/chargebee/models/invoice.rb', line 162

def self.stop_dunning(id, params={}, env=nil, headers={})
  jsonKeys = { 
  }
  options = {
      :isIdempotent => true
    }
  Request.send('post', uri_path("invoices",id.to_s,"stop_dunning"), params, env, headers,nil, false, jsonKeys, options, "invoice", "stopDunning")
end

.sync_usages(id, env = nil, headers = {}) ⇒ Object



207
208
209
210
211
212
213
214
# File 'lib/chargebee/models/invoice.rb', line 207

def self.sync_usages(id, env=nil, headers={})
  jsonKeys = { 
  }
  options = {
      :isIdempotent => true
    }
  Request.send('post', uri_path("invoices",id.to_s,"sync_usages"), {}, env, headers,nil, false, jsonKeys, options, "invoice", "syncUsages")
end

.update_details(id, params = {}, env = nil, headers = {}) ⇒ Object



422
423
424
425
426
427
428
429
# File 'lib/chargebee/models/invoice.rb', line 422

def self.update_details(id, params={}, env=nil, headers={})
  jsonKeys = { 
  }
  options = {
      :isIdempotent => true
    }
  Request.send('post', uri_path("invoices",id.to_s,"update_details"), params, env, headers,nil, false, jsonKeys, options, "invoice", "updateDetails")
end

.void_invoice(id, params = {}, env = nil, headers = {}) ⇒ Object



395
396
397
398
399
400
401
402
# File 'lib/chargebee/models/invoice.rb', line 395

def self.void_invoice(id, params={}, env=nil, headers={})
  jsonKeys = { 
  }
  options = {
      :isIdempotent => true
    }
  Request.send('post', uri_path("invoices",id.to_s,"void"), params, env, headers,nil, false, jsonKeys, options, "invoice", "voidInvoice")
end

.write_off(id, params = {}, env = nil, headers = {}) ⇒ Object



404
405
406
407
408
409
410
411
# File 'lib/chargebee/models/invoice.rb', line 404

def self.write_off(id, params={}, env=nil, headers={})
  jsonKeys = { 
  }
  options = {
      :isIdempotent => true
    }
  Request.send('post', uri_path("invoices",id.to_s,"write_off"), params, env, headers,nil, false, jsonKeys, options, "invoice", "writeOff")
end