Class: ChargeBee::Transaction

Inherits:
Model
  • Object
show all
Defined in:
lib/chargebee/models/transaction.rb

Defined Under Namespace

Classes: GatewayErrorDetail, LinkedCreditNote, LinkedInvoice, LinkedPayment, LinkedRefund, NetworkTransactionDetail

Instance Attribute Summary collapse

Class Method Summary collapse

Methods inherited from Model

construct, #init_dependant, #init_dependant_list, #initialize, #inspect, #load, #method_missing, #replace_white_space_with_underscore, #respond_to_missing?, #to_s, uri_path

Constructor Details

This class inherits a constructor from ChargeBee::Model

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class ChargeBee::Model

Instance Attribute Details

#amount ⇒ Object

Returns the value of attribute amount.



28
29
30
# File 'lib/chargebee/models/transaction.rb', line 28

def amount
  @amount
end

#amount_capturable ⇒ Object

Returns the value of attribute amount_capturable.



28
29
30
# File 'lib/chargebee/models/transaction.rb', line 28

def amount_capturable
  @amount_capturable
end

#amount_unused ⇒ Object

Returns the value of attribute amount_unused.



28
29
30
# File 'lib/chargebee/models/transaction.rb', line 28

def amount_unused
  @amount_unused
end

#authorization_reason ⇒ Object

Returns the value of attribute authorization_reason.



28
29
30
# File 'lib/chargebee/models/transaction.rb', line 28

def authorization_reason
  @authorization_reason
end

#business_entity_id ⇒ Object

Returns the value of attribute business_entity_id.



28
29
30
# File 'lib/chargebee/models/transaction.rb', line 28

def business_entity_id
  @business_entity_id
end

#currency_code ⇒ Object

Returns the value of attribute currency_code.



28
29
30
# File 'lib/chargebee/models/transaction.rb', line 28

def currency_code
  @currency_code
end

#custom_payment_method_id ⇒ Object

Returns the value of attribute custom_payment_method_id.



28
29
30
# File 'lib/chargebee/models/transaction.rb', line 28

def custom_payment_method_id
  @custom_payment_method_id
end

#custom_payment_method_name ⇒ Object

Returns the value of attribute custom_payment_method_name.



28
29
30
# File 'lib/chargebee/models/transaction.rb', line 28

def custom_payment_method_name
  @custom_payment_method_name
end

#customer_id ⇒ Object

Returns the value of attribute customer_id.



28
29
30
# File 'lib/chargebee/models/transaction.rb', line 28

def customer_id
  @customer_id
end

#date ⇒ Object

Returns the value of attribute date.



28
29
30
# File 'lib/chargebee/models/transaction.rb', line 28

def date
  @date
end

#deleted ⇒ Object

Returns the value of attribute deleted.



28
29
30
# File 'lib/chargebee/models/transaction.rb', line 28

def deleted
  @deleted
end

#error_code ⇒ Object

Returns the value of attribute error_code.



28
29
30
# File 'lib/chargebee/models/transaction.rb', line 28

def error_code
  @error_code
end

#error_detail ⇒ Object

Returns the value of attribute error_detail.



28
29
30
# File 'lib/chargebee/models/transaction.rb', line 28

def error_detail
  @error_detail
end

#error_text ⇒ Object

Returns the value of attribute error_text.



28
29
30
# File 'lib/chargebee/models/transaction.rb', line 28

def error_text
  @error_text
end

#exchange_rate ⇒ Object

Returns the value of attribute exchange_rate.



28
29
30
# File 'lib/chargebee/models/transaction.rb', line 28

def exchange_rate
  @exchange_rate
end

#fraud_flag ⇒ Object

Returns the value of attribute fraud_flag.



28
29
30
# File 'lib/chargebee/models/transaction.rb', line 28

def fraud_flag
  @fraud_flag
end

#fraud_reason ⇒ Object

Returns the value of attribute fraud_reason.



28
29
30
# File 'lib/chargebee/models/transaction.rb', line 28

def fraud_reason
  @fraud_reason
end

#gateway ⇒ Object

Returns the value of attribute gateway.



28
29
30
# File 'lib/chargebee/models/transaction.rb', line 28

def gateway
  @gateway
end

#gateway_account_id ⇒ Object

Returns the value of attribute gateway_account_id.



28
29
30
# File 'lib/chargebee/models/transaction.rb', line 28

def 
  @gateway_account_id
end

#id ⇒ Object

Returns the value of attribute id.



28
29
30
# File 'lib/chargebee/models/transaction.rb', line 28

def id
  @id
end

#id_at_gateway ⇒ Object

Returns the value of attribute id_at_gateway.



28
29
30
# File 'lib/chargebee/models/transaction.rb', line 28

def id_at_gateway
  @id_at_gateway
end

#iin ⇒ Object

Returns the value of attribute iin.



28
29
30
# File 'lib/chargebee/models/transaction.rb', line 28

def iin
  @iin
end

#initiator_type ⇒ Object

Returns the value of attribute initiator_type.



28
29
30
# File 'lib/chargebee/models/transaction.rb', line 28

def initiator_type
  @initiator_type
end

#last4 ⇒ Object

Returns the value of attribute last4.



28
29
30
# File 'lib/chargebee/models/transaction.rb', line 28

def last4
  @last4
end

#linked_credit_notes ⇒ Object

Returns the value of attribute linked_credit_notes.



28
29
30
# File 'lib/chargebee/models/transaction.rb', line 28

def linked_credit_notes
  @linked_credit_notes
end

#linked_invoices ⇒ Object

Returns the value of attribute linked_invoices.



28
29
30
# File 'lib/chargebee/models/transaction.rb', line 28

def linked_invoices
  @linked_invoices
end

#linked_payments ⇒ Object

Returns the value of attribute linked_payments.



28
29
30
# File 'lib/chargebee/models/transaction.rb', line 28

def linked_payments
  @linked_payments
end

#linked_refunds ⇒ Object

Returns the value of attribute linked_refunds.



28
29
30
# File 'lib/chargebee/models/transaction.rb', line 28

def linked_refunds
  @linked_refunds
end

#masked_card_number ⇒ Object

Returns the value of attribute masked_card_number.



28
29
30
# File 'lib/chargebee/models/transaction.rb', line 28

def masked_card_number
  @masked_card_number
end

#merchant_reference_id ⇒ Object

Returns the value of attribute merchant_reference_id.



28
29
30
# File 'lib/chargebee/models/transaction.rb', line 28

def merchant_reference_id
  @merchant_reference_id
end

#network_transaction_details ⇒ Object

Returns the value of attribute network_transaction_details.



28
29
30
# File 'lib/chargebee/models/transaction.rb', line 28

def network_transaction_details
  @network_transaction_details
end

#payment_method ⇒ Object

Returns the value of attribute payment_method.



28
29
30
# File 'lib/chargebee/models/transaction.rb', line 28

def payment_method
  @payment_method
end

#payment_method_details ⇒ Object

Returns the value of attribute payment_method_details.



28
29
30
# File 'lib/chargebee/models/transaction.rb', line 28

def payment_method_details
  @payment_method_details
end

#payment_source_id ⇒ Object

Returns the value of attribute payment_source_id.



28
29
30
# File 'lib/chargebee/models/transaction.rb', line 28

def payment_source_id
  @payment_source_id
end

#reference_authorization_id ⇒ Object

Returns the value of attribute reference_authorization_id.



28
29
30
# File 'lib/chargebee/models/transaction.rb', line 28

def reference_authorization_id
  @reference_authorization_id
end

#reference_number ⇒ Object

Returns the value of attribute reference_number.



28
29
30
# File 'lib/chargebee/models/transaction.rb', line 28

def reference_number
  @reference_number
end

#reference_transaction_id ⇒ Object

Returns the value of attribute reference_transaction_id.



28
29
30
# File 'lib/chargebee/models/transaction.rb', line 28

def reference_transaction_id
  @reference_transaction_id
end

#refunded_txn_id ⇒ Object

Returns the value of attribute refunded_txn_id.



28
29
30
# File 'lib/chargebee/models/transaction.rb', line 28

def refunded_txn_id
  @refunded_txn_id
end

#resource_version ⇒ Object

Returns the value of attribute resource_version.



28
29
30
# File 'lib/chargebee/models/transaction.rb', line 28

def resource_version
  @resource_version
end

#reversal_transaction_id ⇒ Object

Returns the value of attribute reversal_transaction_id.



28
29
30
# File 'lib/chargebee/models/transaction.rb', line 28

def reversal_transaction_id
  @reversal_transaction_id
end

#settled_at ⇒ Object

Returns the value of attribute settled_at.



28
29
30
# File 'lib/chargebee/models/transaction.rb', line 28

def settled_at
  @settled_at
end

#status ⇒ Object

Returns the value of attribute status.



28
29
30
# File 'lib/chargebee/models/transaction.rb', line 28

def status
  @status
end

#subscription_id ⇒ Object

Returns the value of attribute subscription_id.



28
29
30
# File 'lib/chargebee/models/transaction.rb', line 28

def subscription_id
  @subscription_id
end

#three_d_secure ⇒ Object

Returns the value of attribute three_d_secure.



28
29
30
# File 'lib/chargebee/models/transaction.rb', line 28

def three_d_secure
  @three_d_secure
end

#type ⇒ Object

Returns the value of attribute type.



28
29
30
# File 'lib/chargebee/models/transaction.rb', line 28

def type
  @type
end

#updated_at ⇒ Object

Returns the value of attribute updated_at.



28
29
30
# File 'lib/chargebee/models/transaction.rb', line 28

def updated_at
  @updated_at
end

#voided_at ⇒ Object

Returns the value of attribute voided_at.



28
29
30
# File 'lib/chargebee/models/transaction.rb', line 28

def voided_at
  @voided_at
end

Class Method Details

.create_authorization(params, env = nil, headers = {}) ⇒ Object

OPERATIONS



40
41
42
43
44
45
46
47
# File 'lib/chargebee/models/transaction.rb', line 40

def self.create_authorization(params, env=nil, headers={})
  jsonKeys = { 
  }
  options = {
      :isIdempotent => true
    }
  Request.send('post', uri_path("transactions","create_authorization"), params, env, headers,nil, false, jsonKeys, options, "transaction", "createAuthorization")
end

.delete_offline_transaction(id, params = {}, env = nil, headers = {}) ⇒ Object



122
123
124
125
126
127
128
129
# File 'lib/chargebee/models/transaction.rb', line 122

def self.delete_offline_transaction(id, params={}, env=nil, headers={})
  jsonKeys = { 
  }
  options = {
      :isIdempotent => true
    }
  Request.send('post', uri_path("transactions",id.to_s,"delete_offline_transaction"), params, env, headers,nil, false, jsonKeys, options, "transaction", "deleteOfflineTransaction")
end

.list(params = {}, env = nil, headers = {}) ⇒ Object



85
86
87
88
89
90
# File 'lib/chargebee/models/transaction.rb', line 85

def self.list(params={}, env=nil, headers={})
  jsonKeys = { 
  }
  options = {}
  Request.send_list_request('get', uri_path("transactions"), params, env, headers,nil, false, jsonKeys, options, "transaction", "list")
end

.payments_for_invoice(id, params = {}, env = nil, headers = {}) ⇒ Object



108
109
110
111
112
113
# File 'lib/chargebee/models/transaction.rb', line 108

def self.payments_for_invoice(id, params={}, env=nil, headers={})
  jsonKeys = { 
  }
  options = {}
  Request.send('get', uri_path("invoices",id.to_s,"payments"), params, env, headers,nil, false, jsonKeys, options, "transaction", "paymentsForInvoice")
end

.reconcile(id, params = {}, env = nil, headers = {}) ⇒ Object



67
68
69
70
71
72
73
74
# File 'lib/chargebee/models/transaction.rb', line 67

def self.reconcile(id, params={}, env=nil, headers={})
  jsonKeys = { 
  }
  options = {
      :isIdempotent => true
    }
  Request.send('post', uri_path("transactions",id.to_s,"reconcile"), params, env, headers,nil, false, jsonKeys, options, "transaction", "reconcile")
end

.record_refund(id, params, env = nil, headers = {}) ⇒ Object



58
59
60
61
62
63
64
65
# File 'lib/chargebee/models/transaction.rb', line 58

def self.record_refund(id, params, env=nil, headers={})
  jsonKeys = { 
  }
  options = {
      :isIdempotent => true
    }
  Request.send('post', uri_path("transactions",id.to_s,"record_refund"), params, env, headers,nil, false, jsonKeys, options, "transaction", "recordRefund")
end

.refund(id, params = {}, env = nil, headers = {}) ⇒ Object



76
77
78
79
80
81
82
83
# File 'lib/chargebee/models/transaction.rb', line 76

def self.refund(id, params={}, env=nil, headers={})
  jsonKeys = { 
  }
  options = {
      :isIdempotent => true
    }
  Request.send('post', uri_path("transactions",id.to_s,"refund"), params, env, headers,nil, false, jsonKeys, options, "transaction", "refund")
end

.retrieve(id, env = nil, headers = {}) ⇒ Object



115
116
117
118
119
120
# File 'lib/chargebee/models/transaction.rb', line 115

def self.retrieve(id, env=nil, headers={})
  jsonKeys = { 
  }
  options = {}
  Request.send('get', uri_path("transactions",id.to_s), {}, env, headers,nil, false, jsonKeys, options, "transaction", "retrieve")
end

.transactions_for_customer(id, params = {}, env = nil, headers = {}) ⇒ Object

Deprecated.

This method is deprecated and will be removed in a future version.



93
94
95
96
97
98
# File 'lib/chargebee/models/transaction.rb', line 93

def self.transactions_for_customer(id, params={}, env=nil, headers={})
  jsonKeys = { 
  }
  options = {}
  Request.send('get', uri_path("customers",id.to_s,"transactions"), params, env, headers,nil, false, jsonKeys, options, "transaction", "transactionsForCustomer")
end

.transactions_for_subscription(id, params = {}, env = nil, headers = {}) ⇒ Object

Deprecated.

This method is deprecated and will be removed in a future version.



101
102
103
104
105
106
# File 'lib/chargebee/models/transaction.rb', line 101

def self.transactions_for_subscription(id, params={}, env=nil, headers={})
  jsonKeys = { 
  }
  options = {}
  Request.send('get', uri_path("subscriptions",id.to_s,"transactions"), params, env, headers,nil, false, jsonKeys, options, "transaction", "transactionsForSubscription")
end

.void_transaction(id, env = nil, headers = {}) ⇒ Object



49
50
51
52
53
54
55
56
# File 'lib/chargebee/models/transaction.rb', line 49

def self.void_transaction(id, env=nil, headers={})
  jsonKeys = { 
  }
  options = {
      :isIdempotent => true
    }
  Request.send('post', uri_path("transactions",id.to_s,"void"), {}, env, headers,nil, false, jsonKeys, options, "transaction", "voidTransaction")
end