Class: ChargeBee::Invoice
- Defined in:
- lib/chargebee/models/invoice.rb
Defined Under Namespace
Classes: AdjustmentCreditNote, AppliedCredit, BillingAddress, Discount, DunningAttempt, Einvoice, IssuedCreditNote, LineItem, LineItemAddress, LineItemCredit, LineItemDiscount, LineItemTax, LineItemTier, LinkedOrder, LinkedPayment, Note, ReferenceTransaction, ShippingAddress, SiteDetailsAtCreation, StatementDescriptor, Tax, TaxOrigin
Instance Attribute Summary collapse
-
#adjustment_credit_notes ⇒ Object
Returns the value of attribute adjustment_credit_notes.
-
#amount_adjusted ⇒ Object
Returns the value of attribute amount_adjusted.
-
#amount_due ⇒ Object
Returns the value of attribute amount_due.
-
#amount_paid ⇒ Object
Returns the value of attribute amount_paid.
-
#amount_to_collect ⇒ Object
Returns the value of attribute amount_to_collect.
-
#applied_credits ⇒ Object
Returns the value of attribute applied_credits.
-
#billing_address ⇒ Object
Returns the value of attribute billing_address.
-
#business_entity_id ⇒ Object
Returns the value of attribute business_entity_id.
-
#channel ⇒ Object
Returns the value of attribute channel.
-
#credits_applied ⇒ Object
Returns the value of attribute credits_applied.
-
#currency_code ⇒ Object
Returns the value of attribute currency_code.
-
#customer_id ⇒ Object
Returns the value of attribute customer_id.
-
#date ⇒ Object
Returns the value of attribute date.
-
#deleted ⇒ Object
Returns the value of attribute deleted.
-
#discounts ⇒ Object
Returns the value of attribute discounts.
-
#due_date ⇒ Object
Returns the value of attribute due_date.
-
#dunning_attempts ⇒ Object
Returns the value of attribute dunning_attempts.
-
#dunning_status ⇒ Object
Returns the value of attribute dunning_status.
-
#einvoice ⇒ Object
Returns the value of attribute einvoice.
-
#exchange_rate ⇒ Object
Returns the value of attribute exchange_rate.
-
#expected_payment_date ⇒ Object
Returns the value of attribute expected_payment_date.
-
#first_invoice ⇒ Object
Returns the value of attribute first_invoice.
-
#generated_at ⇒ Object
Returns the value of attribute generated_at.
-
#has_advance_charges ⇒ Object
Returns the value of attribute has_advance_charges.
-
#id ⇒ Object
Returns the value of attribute id.
-
#is_gifted ⇒ Object
Returns the value of attribute is_gifted.
-
#issued_credit_notes ⇒ Object
Returns the value of attribute issued_credit_notes.
-
#line_item_addresses ⇒ Object
Returns the value of attribute line_item_addresses.
-
#line_item_credits ⇒ Object
Returns the value of attribute line_item_credits.
-
#line_item_discounts ⇒ Object
Returns the value of attribute line_item_discounts.
-
#line_item_taxes ⇒ Object
Returns the value of attribute line_item_taxes.
-
#line_item_tiers ⇒ Object
Returns the value of attribute line_item_tiers.
-
#line_items ⇒ Object
Returns the value of attribute line_items.
-
#line_items_next_offset ⇒ Object
Returns the value of attribute line_items_next_offset.
-
#linked_orders ⇒ Object
Returns the value of attribute linked_orders.
-
#linked_payments ⇒ Object
Returns the value of attribute linked_payments.
-
#local_currency_code ⇒ Object
Returns the value of attribute local_currency_code.
-
#local_currency_exchange_rate ⇒ Object
Returns the value of attribute local_currency_exchange_rate.
-
#net_term_days ⇒ Object
Returns the value of attribute net_term_days.
-
#new_sales_amount ⇒ Object
Returns the value of attribute new_sales_amount.
-
#next_retry_at ⇒ Object
Returns the value of attribute next_retry_at.
-
#notes ⇒ Object
Returns the value of attribute notes.
-
#paid_at ⇒ Object
Returns the value of attribute paid_at.
-
#payment_owner ⇒ Object
Returns the value of attribute payment_owner.
-
#po_number ⇒ Object
Returns the value of attribute po_number.
-
#price_type ⇒ Object
Returns the value of attribute price_type.
-
#recurring ⇒ Object
Returns the value of attribute recurring.
-
#reference_transactions ⇒ Object
Returns the value of attribute reference_transactions.
-
#resource_version ⇒ Object
Returns the value of attribute resource_version.
-
#round_off_amount ⇒ Object
Returns the value of attribute round_off_amount.
-
#shipping_address ⇒ Object
Returns the value of attribute shipping_address.
-
#site_details_at_creation ⇒ Object
Returns the value of attribute site_details_at_creation.
-
#statement_descriptor ⇒ Object
Returns the value of attribute statement_descriptor.
-
#status ⇒ Object
Returns the value of attribute status.
-
#sub_total ⇒ Object
Returns the value of attribute sub_total.
-
#sub_total_in_local_currency ⇒ Object
Returns the value of attribute sub_total_in_local_currency.
-
#subscription_id ⇒ Object
Returns the value of attribute subscription_id.
-
#tax ⇒ Object
Returns the value of attribute tax.
-
#tax_category ⇒ Object
Returns the value of attribute tax_category.
-
#tax_origin ⇒ Object
Returns the value of attribute tax_origin.
-
#taxes ⇒ Object
Returns the value of attribute taxes.
-
#term_finalized ⇒ Object
Returns the value of attribute term_finalized.
-
#total ⇒ Object
Returns the value of attribute total.
-
#total_in_local_currency ⇒ Object
Returns the value of attribute total_in_local_currency.
-
#updated_at ⇒ Object
Returns the value of attribute updated_at.
-
#vat_number ⇒ Object
Returns the value of attribute vat_number.
-
#vat_number_prefix ⇒ Object
Returns the value of attribute vat_number_prefix.
-
#void_reason_code ⇒ Object
Returns the value of attribute void_reason_code.
-
#voided_at ⇒ Object
Returns the value of attribute voided_at.
-
#write_off_amount ⇒ Object
Returns the value of attribute write_off_amount.
Class Method Summary collapse
- .add_addon_charge(id, params, env = nil, headers = {}) ⇒ Object
- .add_charge(id, params, env = nil, headers = {}) ⇒ Object
- .add_charge_item(id, params, env = nil, headers = {}) ⇒ Object
- .apply_credits(id, params = {}, env = nil, headers = {}) ⇒ Object
- .apply_payment_schedule_scheme(id, params, env = nil, headers = {}) ⇒ Object
- .apply_payments(id, params = {}, env = nil, headers = {}) ⇒ Object
- .charge(params, env = nil, headers = {}) ⇒ Object
- .charge_addon(params, env = nil, headers = {}) ⇒ Object
- .close(id, params = {}, env = nil, headers = {}) ⇒ Object
- .collect_payment(id, params = {}, env = nil, headers = {}) ⇒ Object
-
.create(params = {}, env = nil, headers = {}) ⇒ Object
OPERATIONS ———–.
-
.create_for_charge_item(params, env = nil, headers = {}) ⇒ Object
deprecated
Deprecated.
This method is deprecated and will be removed in a future version.
- .create_for_charge_items_and_charges(params, env = nil, headers = {}) ⇒ Object
- .delete(id, params = {}, env = nil, headers = {}) ⇒ Object
- .delete_line_items(id, params = {}, env = nil, headers = {}) ⇒ Object
- .download_einvoice(id, env = nil, headers = {}) ⇒ Object
- .import_invoice(params, env = nil, headers = {}) ⇒ Object
-
.invoices_for_customer(id, params = {}, env = nil, headers = {}) ⇒ Object
deprecated
Deprecated.
This method is deprecated and will be removed in a future version.
-
.invoices_for_subscription(id, params = {}, env = nil, headers = {}) ⇒ Object
deprecated
Deprecated.
This method is deprecated and will be removed in a future version.
- .list(params = {}, env = nil, headers = {}) ⇒ Object
- .list_payment_reference_numbers(params = {}, env = nil, headers = {}) ⇒ Object
- .pause_dunning(id, params, env = nil, headers = {}) ⇒ Object
- .payment_schedules(id, env = nil, headers = {}) ⇒ Object
- .pdf(id, params = {}, env = nil, headers = {}) ⇒ Object
- .record_payment(id, params, env = nil, headers = {}) ⇒ Object
- .record_refund(id, params, env = nil, headers = {}) ⇒ Object
- .record_tax_withheld(id, params, env = nil, headers = {}) ⇒ Object
- .refund(id, params = {}, env = nil, headers = {}) ⇒ Object
- .remove_credit_note(id, params, env = nil, headers = {}) ⇒ Object
- .remove_payment(id, params, env = nil, headers = {}) ⇒ Object
- .remove_tax_withheld(id, params, env = nil, headers = {}) ⇒ Object
- .resend_einvoice(id, env = nil, headers = {}) ⇒ Object
- .resume_dunning(id, params = {}, env = nil, headers = {}) ⇒ Object
- .retrieve(id, params = {}, env = nil, headers = {}) ⇒ Object
- .send_einvoice(id, env = nil, headers = {}) ⇒ Object
- .stop_dunning(id, params = {}, env = nil, headers = {}) ⇒ Object
- .sync_usages(id, env = nil, headers = {}) ⇒ Object
- .update_details(id, params = {}, env = nil, headers = {}) ⇒ Object
- .void_invoice(id, params = {}, env = nil, headers = {}) ⇒ Object
- .write_off(id, params = {}, env = nil, headers = {}) ⇒ Object
Methods inherited from Model
construct, #init_dependant, #init_dependant_list, #initialize, #inspect, #load, #method_missing, #replace_white_space_with_underscore, #respond_to_missing?, #to_s, uri_path
Constructor Details
This class inherits a constructor from ChargeBee::Model
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class ChargeBee::Model
Instance Attribute Details
#adjustment_credit_notes ⇒ Object
Returns the value of attribute adjustment_credit_notes.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def adjustment_credit_notes @adjustment_credit_notes end |
#amount_adjusted ⇒ Object
Returns the value of attribute amount_adjusted.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def amount_adjusted @amount_adjusted end |
#amount_due ⇒ Object
Returns the value of attribute amount_due.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def amount_due @amount_due end |
#amount_paid ⇒ Object
Returns the value of attribute amount_paid.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def amount_paid @amount_paid end |
#amount_to_collect ⇒ Object
Returns the value of attribute amount_to_collect.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def amount_to_collect @amount_to_collect end |
#applied_credits ⇒ Object
Returns the value of attribute applied_credits.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def applied_credits @applied_credits end |
#billing_address ⇒ Object
Returns the value of attribute billing_address.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def billing_address @billing_address end |
#business_entity_id ⇒ Object
Returns the value of attribute business_entity_id.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def business_entity_id @business_entity_id end |
#channel ⇒ Object
Returns the value of attribute channel.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def channel @channel end |
#credits_applied ⇒ Object
Returns the value of attribute credits_applied.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def credits_applied @credits_applied end |
#currency_code ⇒ Object
Returns the value of attribute currency_code.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def currency_code @currency_code end |
#customer_id ⇒ Object
Returns the value of attribute customer_id.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def customer_id @customer_id end |
#date ⇒ Object
Returns the value of attribute date.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def date @date end |
#deleted ⇒ Object
Returns the value of attribute deleted.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def deleted @deleted end |
#discounts ⇒ Object
Returns the value of attribute discounts.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def discounts @discounts end |
#due_date ⇒ Object
Returns the value of attribute due_date.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def due_date @due_date end |
#dunning_attempts ⇒ Object
Returns the value of attribute dunning_attempts.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def dunning_attempts @dunning_attempts end |
#dunning_status ⇒ Object
Returns the value of attribute dunning_status.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def dunning_status @dunning_status end |
#einvoice ⇒ Object
Returns the value of attribute einvoice.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def einvoice @einvoice end |
#exchange_rate ⇒ Object
Returns the value of attribute exchange_rate.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def exchange_rate @exchange_rate end |
#expected_payment_date ⇒ Object
Returns the value of attribute expected_payment_date.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def expected_payment_date @expected_payment_date end |
#first_invoice ⇒ Object
Returns the value of attribute first_invoice.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def first_invoice @first_invoice end |
#generated_at ⇒ Object
Returns the value of attribute generated_at.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def generated_at @generated_at end |
#has_advance_charges ⇒ Object
Returns the value of attribute has_advance_charges.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def has_advance_charges @has_advance_charges end |
#id ⇒ Object
Returns the value of attribute id.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def id @id end |
#is_gifted ⇒ Object
Returns the value of attribute is_gifted.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def is_gifted @is_gifted end |
#issued_credit_notes ⇒ Object
Returns the value of attribute issued_credit_notes.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def issued_credit_notes @issued_credit_notes end |
#line_item_addresses ⇒ Object
Returns the value of attribute line_item_addresses.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def line_item_addresses @line_item_addresses end |
#line_item_credits ⇒ Object
Returns the value of attribute line_item_credits.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def line_item_credits @line_item_credits end |
#line_item_discounts ⇒ Object
Returns the value of attribute line_item_discounts.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def line_item_discounts @line_item_discounts end |
#line_item_taxes ⇒ Object
Returns the value of attribute line_item_taxes.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def line_item_taxes @line_item_taxes end |
#line_item_tiers ⇒ Object
Returns the value of attribute line_item_tiers.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def line_item_tiers @line_item_tiers end |
#line_items ⇒ Object
Returns the value of attribute line_items.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def line_items @line_items end |
#line_items_next_offset ⇒ Object
Returns the value of attribute line_items_next_offset.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def line_items_next_offset @line_items_next_offset end |
#linked_orders ⇒ Object
Returns the value of attribute linked_orders.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def linked_orders @linked_orders end |
#linked_payments ⇒ Object
Returns the value of attribute linked_payments.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def linked_payments @linked_payments end |
#local_currency_code ⇒ Object
Returns the value of attribute local_currency_code.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def local_currency_code @local_currency_code end |
#local_currency_exchange_rate ⇒ Object
Returns the value of attribute local_currency_exchange_rate.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def local_currency_exchange_rate @local_currency_exchange_rate end |
#net_term_days ⇒ Object
Returns the value of attribute net_term_days.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def net_term_days @net_term_days end |
#new_sales_amount ⇒ Object
Returns the value of attribute new_sales_amount.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def new_sales_amount @new_sales_amount end |
#next_retry_at ⇒ Object
Returns the value of attribute next_retry_at.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def next_retry_at @next_retry_at end |
#notes ⇒ Object
Returns the value of attribute notes.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def notes @notes end |
#paid_at ⇒ Object
Returns the value of attribute paid_at.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def paid_at @paid_at end |
#payment_owner ⇒ Object
Returns the value of attribute payment_owner.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def payment_owner @payment_owner end |
#po_number ⇒ Object
Returns the value of attribute po_number.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def po_number @po_number end |
#price_type ⇒ Object
Returns the value of attribute price_type.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def price_type @price_type end |
#recurring ⇒ Object
Returns the value of attribute recurring.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def recurring @recurring end |
#reference_transactions ⇒ Object
Returns the value of attribute reference_transactions.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def reference_transactions @reference_transactions end |
#resource_version ⇒ Object
Returns the value of attribute resource_version.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def resource_version @resource_version end |
#round_off_amount ⇒ Object
Returns the value of attribute round_off_amount.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def round_off_amount @round_off_amount end |
#shipping_address ⇒ Object
Returns the value of attribute shipping_address.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def shipping_address @shipping_address end |
#site_details_at_creation ⇒ Object
Returns the value of attribute site_details_at_creation.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def site_details_at_creation @site_details_at_creation end |
#statement_descriptor ⇒ Object
Returns the value of attribute statement_descriptor.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def statement_descriptor @statement_descriptor end |
#status ⇒ Object
Returns the value of attribute status.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def status @status end |
#sub_total ⇒ Object
Returns the value of attribute sub_total.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def sub_total @sub_total end |
#sub_total_in_local_currency ⇒ Object
Returns the value of attribute sub_total_in_local_currency.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def sub_total_in_local_currency @sub_total_in_local_currency end |
#subscription_id ⇒ Object
Returns the value of attribute subscription_id.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def subscription_id @subscription_id end |
#tax ⇒ Object
Returns the value of attribute tax.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def tax @tax end |
#tax_category ⇒ Object
Returns the value of attribute tax_category.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def tax_category @tax_category end |
#tax_origin ⇒ Object
Returns the value of attribute tax_origin.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def tax_origin @tax_origin end |
#taxes ⇒ Object
Returns the value of attribute taxes.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def taxes @taxes end |
#term_finalized ⇒ Object
Returns the value of attribute term_finalized.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def term_finalized @term_finalized end |
#total ⇒ Object
Returns the value of attribute total.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def total @total end |
#total_in_local_currency ⇒ Object
Returns the value of attribute total_in_local_currency.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def total_in_local_currency @total_in_local_currency end |
#updated_at ⇒ Object
Returns the value of attribute updated_at.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def updated_at @updated_at end |
#vat_number ⇒ Object
Returns the value of attribute vat_number.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def vat_number @vat_number end |
#vat_number_prefix ⇒ Object
Returns the value of attribute vat_number_prefix.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def vat_number_prefix @vat_number_prefix end |
#void_reason_code ⇒ Object
Returns the value of attribute void_reason_code.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def void_reason_code @void_reason_code end |
#voided_at ⇒ Object
Returns the value of attribute voided_at.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def voided_at @voided_at end |
#write_off_amount ⇒ Object
Returns the value of attribute write_off_amount.
92 93 94 |
# File 'lib/chargebee/models/invoice.rb', line 92 def write_off_amount @write_off_amount end |
Class Method Details
.add_addon_charge(id, params, env = nil, headers = {}) ⇒ Object
292 293 294 295 296 297 298 299 |
# File 'lib/chargebee/models/invoice.rb', line 292 def self.add_addon_charge(id, params, env=nil, headers={}) jsonKeys = { } = { :isIdempotent => true } Request.send('post', uri_path("invoices",id.to_s,"add_addon_charge"), params, env, headers,nil, false, jsonKeys, ) end |
.add_charge(id, params, env = nil, headers = {}) ⇒ Object
283 284 285 286 287 288 289 290 |
# File 'lib/chargebee/models/invoice.rb', line 283 def self.add_charge(id, params, env=nil, headers={}) jsonKeys = { } = { :isIdempotent => true } Request.send('post', uri_path("invoices",id.to_s,"add_charge"), params, env, headers,nil, false, jsonKeys, ) end |
.add_charge_item(id, params, env = nil, headers = {}) ⇒ Object
301 302 303 304 305 306 307 308 |
# File 'lib/chargebee/models/invoice.rb', line 301 def self.add_charge_item(id, params, env=nil, headers={}) jsonKeys = { } = { :isIdempotent => true } Request.send('post', uri_path("invoices",id.to_s,"add_charge_item"), params, env, headers,nil, false, jsonKeys, ) end |
.apply_credits(id, params = {}, env = nil, headers = {}) ⇒ Object
221 222 223 224 225 226 227 228 |
# File 'lib/chargebee/models/invoice.rb', line 221 def self.apply_credits(id, params={}, env=nil, headers={}) jsonKeys = { } = { :isIdempotent => true } Request.send('post', uri_path("invoices",id.to_s,"apply_credits"), params, env, headers,nil, false, jsonKeys, ) end |
.apply_payment_schedule_scheme(id, params, env = nil, headers = {}) ⇒ Object
427 428 429 430 431 432 433 434 |
# File 'lib/chargebee/models/invoice.rb', line 427 def self.apply_payment_schedule_scheme(id, params, env=nil, headers={}) jsonKeys = { } = { :isIdempotent => true } Request.send('post', uri_path("invoices",id.to_s,"apply_payment_schedule_scheme"), params, env, headers,nil, false, jsonKeys, ) end |
.apply_payments(id, params = {}, env = nil, headers = {}) ⇒ Object
194 195 196 197 198 199 200 201 |
# File 'lib/chargebee/models/invoice.rb', line 194 def self.apply_payments(id, params={}, env=nil, headers={}) jsonKeys = { } = { :isIdempotent => true } Request.send('post', uri_path("invoices",id.to_s,"apply_payments"), params, env, headers,nil, false, jsonKeys, ) end |
.charge(params, env = nil, headers = {}) ⇒ Object
130 131 132 133 134 135 136 137 |
# File 'lib/chargebee/models/invoice.rb', line 130 def self.charge(params, env=nil, headers={}) jsonKeys = { } = { :isIdempotent => true } Request.send('post', uri_path("invoices","charge"), params, env, headers,nil, false, jsonKeys, ) end |
.charge_addon(params, env = nil, headers = {}) ⇒ Object
139 140 141 142 143 144 145 146 |
# File 'lib/chargebee/models/invoice.rb', line 139 def self.charge_addon(params, env=nil, headers={}) jsonKeys = { } = { :isIdempotent => true } Request.send('post', uri_path("invoices","charge_addon"), params, env, headers,nil, false, jsonKeys, ) end |
.close(id, params = {}, env = nil, headers = {}) ⇒ Object
310 311 312 313 314 315 316 317 |
# File 'lib/chargebee/models/invoice.rb', line 310 def self.close(id, params={}, env=nil, headers={}) jsonKeys = { } = { :isIdempotent => true } Request.send('post', uri_path("invoices",id.to_s,"close"), params, env, headers,nil, false, jsonKeys, ) end |
.collect_payment(id, params = {}, env = nil, headers = {}) ⇒ Object
319 320 321 322 323 324 325 326 |
# File 'lib/chargebee/models/invoice.rb', line 319 def self.collect_payment(id, params={}, env=nil, headers={}) jsonKeys = { } = { :isIdempotent => true } Request.send('post', uri_path("invoices",id.to_s,"collect_payment"), params, env, headers,nil, false, jsonKeys, ) end |
.create(params = {}, env = nil, headers = {}) ⇒ Object
OPERATIONS
108 109 110 111 112 113 114 115 116 117 |
# File 'lib/chargebee/models/invoice.rb', line 108 def self.create(params={}, env=nil, headers={}) jsonKeys = { :additional_information => 1, :billing_address => 1, } = { :isIdempotent => true } Request.send('post', uri_path("invoices"), params, env, headers,nil, false, jsonKeys, ) end |
.create_for_charge_item(params, env = nil, headers = {}) ⇒ Object
This method is deprecated and will be removed in a future version.
149 150 151 152 153 154 155 156 |
# File 'lib/chargebee/models/invoice.rb', line 149 def self.create_for_charge_item(params, env=nil, headers={}) jsonKeys = { } = { :isIdempotent => true } Request.send('post', uri_path("invoices","create_for_charge_item"), params, env, headers,nil, false, jsonKeys, ) end |
.create_for_charge_items_and_charges(params, env = nil, headers = {}) ⇒ Object
119 120 121 122 123 124 125 126 127 128 |
# File 'lib/chargebee/models/invoice.rb', line 119 def self.create_for_charge_items_and_charges(params, env=nil, headers={}) jsonKeys = { :additional_information => 1, :billing_address => 1, } = { :isIdempotent => true } Request.send('post', uri_path("invoices","create_for_charge_items_and_charges"), params, env, headers,nil, false, jsonKeys, ) end |
.delete(id, params = {}, env = nil, headers = {}) ⇒ Object
409 410 411 412 413 414 415 416 |
# File 'lib/chargebee/models/invoice.rb', line 409 def self.delete(id, params={}, env=nil, headers={}) jsonKeys = { } = { :isIdempotent => true } Request.send('post', uri_path("invoices",id.to_s,"delete"), params, env, headers,nil, false, jsonKeys, ) end |
.delete_line_items(id, params = {}, env = nil, headers = {}) ⇒ Object
212 213 214 215 216 217 218 219 |
# File 'lib/chargebee/models/invoice.rb', line 212 def self.delete_line_items(id, params={}, env=nil, headers={}) jsonKeys = { } = { :isIdempotent => true } Request.send('post', uri_path("invoices",id.to_s,"delete_line_items"), params, env, headers,nil, false, jsonKeys, ) end |
.download_einvoice(id, env = nil, headers = {}) ⇒ Object
269 270 271 272 273 274 |
# File 'lib/chargebee/models/invoice.rb', line 269 def self.download_einvoice(id, env=nil, headers={}) jsonKeys = { } = {} Request.send('get', uri_path("invoices",id.to_s,"download_einvoice"), {}, env, headers,nil, false, jsonKeys, ) end |
.import_invoice(params, env = nil, headers = {}) ⇒ Object
185 186 187 188 189 190 191 192 |
# File 'lib/chargebee/models/invoice.rb', line 185 def self.import_invoice(params, env=nil, headers={}) jsonKeys = { } = { :isIdempotent => true } Request.send('post', uri_path("invoices","import_invoice"), params, env, headers,nil, false, jsonKeys, ) end |
.invoices_for_customer(id, params = {}, env = nil, headers = {}) ⇒ Object
This method is deprecated and will be removed in a future version.
238 239 240 241 242 243 |
# File 'lib/chargebee/models/invoice.rb', line 238 def self.invoices_for_customer(id, params={}, env=nil, headers={}) jsonKeys = { } = {} Request.send('get', uri_path("customers",id.to_s,"invoices"), params, env, headers,nil, false, jsonKeys, ) end |
.invoices_for_subscription(id, params = {}, env = nil, headers = {}) ⇒ Object
This method is deprecated and will be removed in a future version.
246 247 248 249 250 251 |
# File 'lib/chargebee/models/invoice.rb', line 246 def self.invoices_for_subscription(id, params={}, env=nil, headers={}) jsonKeys = { } = {} Request.send('get', uri_path("subscriptions",id.to_s,"invoices"), params, env, headers,nil, false, jsonKeys, ) end |
.list(params = {}, env = nil, headers = {}) ⇒ Object
230 231 232 233 234 235 |
# File 'lib/chargebee/models/invoice.rb', line 230 def self.list(params={}, env=nil, headers={}) jsonKeys = { } = {} Request.send_list_request('get', uri_path("invoices"), params, env, headers,nil, false, jsonKeys, ) end |
.list_payment_reference_numbers(params = {}, env = nil, headers = {}) ⇒ Object
276 277 278 279 280 281 |
# File 'lib/chargebee/models/invoice.rb', line 276 def self.list_payment_reference_numbers(params={}, env=nil, headers={}) jsonKeys = { } = {} Request.send('get', uri_path("invoices","payment_reference_numbers"), params, env, headers,nil, false, jsonKeys, ) end |
.pause_dunning(id, params, env = nil, headers = {}) ⇒ Object
167 168 169 170 171 172 173 174 |
# File 'lib/chargebee/models/invoice.rb', line 167 def self.pause_dunning(id, params, env=nil, headers={}) jsonKeys = { } = { :isIdempotent => true } Request.send('post', uri_path("invoices",id.to_s,"pause_dunning"), params, env, headers,nil, false, jsonKeys, ) end |
.payment_schedules(id, env = nil, headers = {}) ⇒ Object
436 437 438 439 440 441 |
# File 'lib/chargebee/models/invoice.rb', line 436 def self.payment_schedules(id, env=nil, headers={}) jsonKeys = { } = {} Request.send('get', uri_path("invoices",id.to_s,"payment_schedules"), {}, env, headers,nil, false, jsonKeys, ) end |
.pdf(id, params = {}, env = nil, headers = {}) ⇒ Object
260 261 262 263 264 265 266 267 |
# File 'lib/chargebee/models/invoice.rb', line 260 def self.pdf(id, params={}, env=nil, headers={}) jsonKeys = { } = { :isIdempotent => true } Request.send('post', uri_path("invoices",id.to_s,"pdf"), params, env, headers,nil, false, jsonKeys, ) end |
.record_payment(id, params, env = nil, headers = {}) ⇒ Object
328 329 330 331 332 333 334 335 |
# File 'lib/chargebee/models/invoice.rb', line 328 def self.record_payment(id, params, env=nil, headers={}) jsonKeys = { } = { :isIdempotent => true } Request.send('post', uri_path("invoices",id.to_s,"record_payment"), params, env, headers,nil, false, jsonKeys, ) end |
.record_refund(id, params, env = nil, headers = {}) ⇒ Object
364 365 366 367 368 369 370 371 |
# File 'lib/chargebee/models/invoice.rb', line 364 def self.record_refund(id, params, env=nil, headers={}) jsonKeys = { } = { :isIdempotent => true } Request.send('post', uri_path("invoices",id.to_s,"record_refund"), params, env, headers,nil, false, jsonKeys, ) end |
.record_tax_withheld(id, params, env = nil, headers = {}) ⇒ Object
337 338 339 340 341 342 343 344 |
# File 'lib/chargebee/models/invoice.rb', line 337 def self.record_tax_withheld(id, params, env=nil, headers={}) jsonKeys = { } = { :isIdempotent => true } Request.send('post', uri_path("invoices",id.to_s,"record_tax_withheld"), params, env, headers,nil, false, jsonKeys, ) end |
.refund(id, params = {}, env = nil, headers = {}) ⇒ Object
355 356 357 358 359 360 361 362 |
# File 'lib/chargebee/models/invoice.rb', line 355 def self.refund(id, params={}, env=nil, headers={}) jsonKeys = { } = { :isIdempotent => true } Request.send('post', uri_path("invoices",id.to_s,"refund"), params, env, headers,nil, false, jsonKeys, ) end |
.remove_credit_note(id, params, env = nil, headers = {}) ⇒ Object
382 383 384 385 386 387 388 389 |
# File 'lib/chargebee/models/invoice.rb', line 382 def self.remove_credit_note(id, params, env=nil, headers={}) jsonKeys = { } = { :isIdempotent => true } Request.send('post', uri_path("invoices",id.to_s,"remove_credit_note"), params, env, headers,nil, false, jsonKeys, ) end |
.remove_payment(id, params, env = nil, headers = {}) ⇒ Object
373 374 375 376 377 378 379 380 |
# File 'lib/chargebee/models/invoice.rb', line 373 def self.remove_payment(id, params, env=nil, headers={}) jsonKeys = { } = { :isIdempotent => true } Request.send('post', uri_path("invoices",id.to_s,"remove_payment"), params, env, headers,nil, false, jsonKeys, ) end |
.remove_tax_withheld(id, params, env = nil, headers = {}) ⇒ Object
346 347 348 349 350 351 352 353 |
# File 'lib/chargebee/models/invoice.rb', line 346 def self.remove_tax_withheld(id, params, env=nil, headers={}) jsonKeys = { } = { :isIdempotent => true } Request.send('post', uri_path("invoices",id.to_s,"remove_tax_withheld"), params, env, headers,nil, false, jsonKeys, ) end |
.resend_einvoice(id, env = nil, headers = {}) ⇒ Object
443 444 445 446 447 448 449 450 |
# File 'lib/chargebee/models/invoice.rb', line 443 def self.resend_einvoice(id, env=nil, headers={}) jsonKeys = { } = { :isIdempotent => true } Request.send('post', uri_path("invoices",id.to_s,"resend_einvoice"), {}, env, headers,nil, false, jsonKeys, ) end |
.resume_dunning(id, params = {}, env = nil, headers = {}) ⇒ Object
176 177 178 179 180 181 182 183 |
# File 'lib/chargebee/models/invoice.rb', line 176 def self.resume_dunning(id, params={}, env=nil, headers={}) jsonKeys = { } = { :isIdempotent => true } Request.send('post', uri_path("invoices",id.to_s,"resume_dunning"), params, env, headers,nil, false, jsonKeys, ) end |
.retrieve(id, params = {}, env = nil, headers = {}) ⇒ Object
253 254 255 256 257 258 |
# File 'lib/chargebee/models/invoice.rb', line 253 def self.retrieve(id, params={}, env=nil, headers={}) jsonKeys = { } = {} Request.send('get', uri_path("invoices",id.to_s), params, env, headers,nil, false, jsonKeys, ) end |
.send_einvoice(id, env = nil, headers = {}) ⇒ Object
452 453 454 455 456 457 458 459 |
# File 'lib/chargebee/models/invoice.rb', line 452 def self.send_einvoice(id, env=nil, headers={}) jsonKeys = { } = { :isIdempotent => true } Request.send('post', uri_path("invoices",id.to_s,"send_einvoice"), {}, env, headers,nil, false, jsonKeys, ) end |
.stop_dunning(id, params = {}, env = nil, headers = {}) ⇒ Object
158 159 160 161 162 163 164 165 |
# File 'lib/chargebee/models/invoice.rb', line 158 def self.stop_dunning(id, params={}, env=nil, headers={}) jsonKeys = { } = { :isIdempotent => true } Request.send('post', uri_path("invoices",id.to_s,"stop_dunning"), params, env, headers,nil, false, jsonKeys, ) end |
.sync_usages(id, env = nil, headers = {}) ⇒ Object
203 204 205 206 207 208 209 210 |
# File 'lib/chargebee/models/invoice.rb', line 203 def self.sync_usages(id, env=nil, headers={}) jsonKeys = { } = { :isIdempotent => true } Request.send('post', uri_path("invoices",id.to_s,"sync_usages"), {}, env, headers,nil, false, jsonKeys, ) end |
.update_details(id, params = {}, env = nil, headers = {}) ⇒ Object
418 419 420 421 422 423 424 425 |
# File 'lib/chargebee/models/invoice.rb', line 418 def self.update_details(id, params={}, env=nil, headers={}) jsonKeys = { } = { :isIdempotent => true } Request.send('post', uri_path("invoices",id.to_s,"update_details"), params, env, headers,nil, false, jsonKeys, ) end |
.void_invoice(id, params = {}, env = nil, headers = {}) ⇒ Object
391 392 393 394 395 396 397 398 |
# File 'lib/chargebee/models/invoice.rb', line 391 def self.void_invoice(id, params={}, env=nil, headers={}) jsonKeys = { } = { :isIdempotent => true } Request.send('post', uri_path("invoices",id.to_s,"void"), params, env, headers,nil, false, jsonKeys, ) end |
.write_off(id, params = {}, env = nil, headers = {}) ⇒ Object
400 401 402 403 404 405 406 407 |
# File 'lib/chargebee/models/invoice.rb', line 400 def self.write_off(id, params={}, env=nil, headers={}) jsonKeys = { } = { :isIdempotent => true } Request.send('post', uri_path("invoices",id.to_s,"write_off"), params, env, headers,nil, false, jsonKeys, ) end |